@@ -5,12 +5,10 @@ u = okcupyd.User()
 p = u.quickmatch()
 
 
-print('Questions for {0}'.format(p.username))
-print('----------')
 for q in p.questions:
     if 'marijuana' in q.text.lower():
         print(q.text)
-        print(q.user_answer)
+        print(q.answer)
         if q.explanation and len(q.explanation):
             print(q.explanation)
         print('')
