@@ -38,6 +38,13 @@ def test_profile_properties():
     assert profile.contacted == False # We want it to be false, not falsy
 
 
+@util.use_cassette
+def test_profile_attractiveness():
+    # TODO: get rid of circular import so you can do this.
+    profile = User().quickmatch()
+    assert 1 < profile.attractiveness < 10001
+
+
 @util.use_cassette(cassette_name='test_profile_contacted')
 def test_contacted():
     profile = User().quickmatch()
